from machine import Pin, ADC, I2C
import ssd1306
from time import sleep

i2c = I2C(scl=Pin(5), sda=Pin(4))  
pot=ADC(0)

oled_width = 128
oled_height = 64
oled = ssd1306.SSD1306_I2C(oled_width, oled_height, i2c)

pin1 = Pin(15, Pin.OUT)
pin2 = Pin(13,  Pin.OUT)
pin3 = Pin(12,  Pin.OUT)
pin4 = Pin(14,  Pin.OUT) 

tiempo = 0.005

WaveDrive=[
  [1,0,0,0],
  [0,1,0,0],
  [0,0,1,0],
  [0,0,0,1]]
  
FullStepDrive=[
  [1,0,0,1],
  [1,1,0,0],
  [0,1,1,0],
  [0,0,1,1]]

HalfStepDrive=[
  [1,0,0,1],
  [1,0,0,0],
  [1,1,0,0],
  [0,1,0,0],
  [0,1,1,0],
  [0,0,1,0],
  [0,0,1,1],
  [0,0,0,1]]
  
#Secuencias sentido de giro HORARIO wavedrive
#===============================================================================
def secuenciaWaveDrive_horario(tiempo):
  for indice in range(2048):
    pin1.value(WaveDrive[indice%4][3])
    pin2.value(WaveDrive[indice%4][2])
    pin3.value(WaveDrive[indice%4][1])
    pin4.value(WaveDrive[indice%4][0])
    sleep(tiempo)      
      
#Secuencias sentido de giro AHORARIO wavedrive    
#===============================================================================    
def secuenciaWaveDrive_Ahorario(tiempo):
  for indice in range(2048):
    pin1.value(WaveDrive[indice%4][0])
    pin2.value(WaveDrive[indice%4][1])
    pin3.value(WaveDrive[indice%4][2])
    pin4.value(WaveDrive[indice%4][3])
    sleep(tiempo)

#Secuencia de paro
#===============================================================================    
def secuenciaParo():
  pin1.value(0)
  pin2.value(0)
  pin3.value(0)
  pin4.value(0)
  sleep(tiempo) 

#Secuencia gira n grados, horario, antihorario
#=============================================================================== 
def giroGrados(grados,tiempo):
  if(grados>=0):
    for indice in range(int((2048/360)*grados)):    
      pin1.value(WaveDrive[indice%4][0])                #horario
      pin2.value(WaveDrive[indice%4][1])
      pin3.value(WaveDrive[indice%4][2])
      pin4.value(WaveDrive[indice%4][3])
      sleep(tiempo)     
  else: 
    for indice in range(int((2048/360)*abs(grados))):  
      pin1.value(WaveDrive[indice%4][3])                #Ahorario
      pin2.value(WaveDrive[indice%4][2])
      pin3.value(WaveDrive[indice%4][1])
      pin4.value(WaveDrive[indice%4][0])
      sleep(tiempo)

#Funcion principal
#===============================================================================    

def main():  
  i=0
  pos_actual=0
            #0123456789012345
  oled.text(' Control de giro', 0, 0 )
  oled.text('angular mediante', 0, 15)
  oled.text(' potenciometro ', 0, 30)   
  oled.text(' DESPLAZANDO...', 0, 45)
  oled.show()

  while(True): 
    nueva_posicion=2*pot.read()
    if(nueva_posicion>pos_actual):
      pos_actual=pos_actual+1  
      pin1.value(WaveDrive[pos_actual%4][3])  #Horario
      pin2.value(WaveDrive[pos_actual%4][2])
      pin3.value(WaveDrive[pos_actual%4][1])
      pin4.value(WaveDrive[pos_actual%4][0])
      sleep(tiempo)     
    elif(nueva_posicion<pos_actual): 
      pos_actual=pos_actual-1
      pin1.value(WaveDrive[pos_actual%4][3])  #Ahorario
      pin2.value(WaveDrive[pos_actual%4][2])
      pin3.value(WaveDrive[pos_actual%4][1])
      pin4.value(WaveDrive[pos_actual%4][0])
      sleep(tiempo)
    else:
      pin1.value(0)                           #Paro
      pin2.value(0)
      pin3.value(0)
      pin4.value(0)
      sleep(tiempo) 
      
      oled.fill(0)
      oled.text('Desplazamiento:', 0, 0 )
      oled.text('Ajuste: '  , 0, 22)
      oled.text('Posicion: ', 0, 38) 
      oled.text(grado_ajuste, 60, 22)
      oled.text(grado_actual, 74, 38)
      oled.show()
     
      
    i=i+1
    if(i>50):
      grado_actual=str(int((360/2048)*pos_actual)) 
      grado_ajuste=str(int((360/2048)*nueva_posicion)) 
      print('Posicion actual: '+grado_actual+' grados, Posicion de ajuste: '+grado_ajuste+' grados')     
      #oled.text(grado_ajuste, 74, 22)
      #oled.text(grado_actual, 74, 38)
      #oled.show()
      
      i=0

#Programa principal  
#=============================================================================== 

main()

#=============================================================================== 



